@@ -19,27 +19,19 @@ from wtfis.clients.abuseipdb import AbuseIpDbClient
 from wtfis.clients.greynoise import GreynoiseClient
 from wtfis.clients.ip2whois import Ip2WhoisClient
 from wtfis.clients.ipwhois import IpWhoisClient
-from wtfis.clients.passivetotal import PTClient
 from wtfis.clients.shodan import ShodanClient
 from wtfis.clients.urlhaus import UrlHausClient
 from wtfis.clients.virustotal import VTClient
+from wtfis.config import Config, parse_args, parse_env
 from wtfis.exceptions import WtfisException
 from wtfis.handlers.domain import DomainHandler
 from wtfis.handlers.ip import IpAddressHandler
-from wtfis.main import (
-    generate_entity_handler,
-    generate_view,
-    main,
-    parse_args,
-    parse_env,
-)
+from wtfis.main import generate_entity_handler, generate_view, main
 from wtfis.models.virustotal import Domain, IpAddress
 from wtfis.ui.view import DomainView, IpAddressView
 
 POSSIBLE_ENV_VARS = [
     "VT_API_KEY",
-    "PT_API_KEY",
-    "PT_API_USER",
     "IP2WHOIS_API_KEY",
     "SHODAN_API_KEY",
     "GREYNOISE_API_KEY",
@@ -82,8 +74,6 @@ def simulate_progress(console):
 def fake_load_dotenv_1(tmp_path):
     fake_env_vars = {
         "VT_API_KEY": "foo",
-        "PT_API_KEY": "bar",
-        "PT_API_USER": "baz@example.com",
         "IP2WHOIS_API_KEY": "alice",
         "SHODAN_API_KEY": "hunter2",
         "GREYNOISE_API_KEY": "upupdowndown",
@@ -139,6 +129,29 @@ def fake_load_dotenv_ip2whois(tmp_path):
     return fake_load_dotenv(tmp_path, fake_env_vars)
 
 
+@pytest.fixture()
+def fake_load_dotenv_all_ok(tmp_path):
+    fake_env_vars = {
+        "VT_API_KEY": "foo",
+        "SHODAN_API_KEY": "hunter2",
+        "GREYNOISE_API_KEY": "bar",
+        "ABUSEIPDB_API_KEY": "dummy",
+        "IP2WHOIS_API_KEY": "alice",
+        "WTFIS_DEFAULTS": "-A",
+    }
+    return fake_load_dotenv(tmp_path, fake_env_vars)
+
+
+@pytest.fixture()
+def fake_load_dotenv_all_invalid(tmp_path):
+    fake_env_vars = {
+        "VT_API_KEY": "foo",
+        "GREYNOISE_API_KEY": "bar",
+        "WTFIS_DEFAULTS": "--all -g",
+    }
+    return fake_load_dotenv(tmp_path, fake_env_vars)
+
+
 class TestArgs:
     def test_basic(self):
         with patch(
@@ -156,6 +169,8 @@ class TestArgs:
             assert args.use_shodan is False
             assert args.use_greynoise is False
             assert args.use_urlhaus is False
+            assert args.use_abuseipdb is False
+            assert args.all is False
 
     def test_display(self):
         with patch(
@@ -344,28 +359,65 @@ class TestArgs:
         assert e.type == SystemExit
         assert e.value.code == 2
 
+    def test_all_ok(self):
+        os.environ["ABUSEIPDB_API_KEY"] = "foo"
+        with patch(
+            "sys.argv",
+            [
+                "main",
+                "1.1.1.1",
+                "-A",
+            ],
+        ):
+            args = parse_args()
+            assert args.all is True
+            assert args.use_abuseipdb is False
+        del os.environ["ABUSEIPDB_API_KEY"]
+
+    def test_all_error(self, capsys):
+        os.environ["SHODAN_API_KEY"] = "foo"
+        with pytest.raises(SystemExit) as e:
+            with patch(
+                "sys.argv",
+                [
+                    "main",
+                    "1.1.1.1",
+                    "-A",
+                    "-s",
+                ],
+            ):
+                parse_args()
+
+        capture = capsys.readouterr()
+
+        assert capture.err == (
+            "usage: main [-h]\n"
+            "main: error: --use-* flags are not accepted when the --all/-A flag is set\n"
+        )
+        assert e.type == SystemExit
+        assert e.value.code == 2
+        del os.environ["SHODAN_API_KEY"]
+
 
 class TestEnvs:
     def test_env_file(self, fake_load_dotenv_1):
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_1):
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_1):
             parse_env()
             assert os.environ["VT_API_KEY"] == "foo"
-            assert os.environ["PT_API_KEY"] == "bar"
-            assert os.environ["PT_API_USER"] == "baz@example.com"
             assert os.environ["IP2WHOIS_API_KEY"] == "alice"
             assert os.environ["SHODAN_API_KEY"] == "hunter2"
             assert os.environ["GREYNOISE_API_KEY"] == "upupdowndown"
             assert os.environ["ABUSEIPDB_API_KEY"] == "dummy"
         unset_env_vars()
 
-    @patch("wtfis.main.load_dotenv", MagicMock())
+    @patch("wtfis.config.load_dotenv", MagicMock())
     def test_required_env_vars(self):
         os.environ["VT_API_KEY"] = "foo"
         parse_env()
         unset_env_vars()
 
-    @patch("wtfis.main.load_dotenv", MagicMock())
-    @patch("wtfis.main.Path.exists")
+    @patch("wtfis.config.load_dotenv", MagicMock())
+    @patch("wtfis.config.Path.exists")
     def test_error(self, mock_exists, capsys):
         mock_exists.return_value = False
 
@@ -385,7 +437,7 @@ class TestEnvs:
 
 class TestDefaults:
     def test_defaults_1(self, fake_load_dotenv_2):
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_2):
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_2):
             with patch(
                 "sys.argv",
                 [
@@ -393,19 +445,24 @@ class TestDefaults:
                     "www.example.com",
                 ],
             ):
-                parse_env()
-                args = parse_args()
-                assert args.entity == "www.example.com"
-                assert args.max_resolutions == 3
-                assert args.no_color is False
-                assert args.one_column is True
-                assert args.use_shodan is True
-                assert args.use_greynoise is False
-                assert args.use_urlhaus is False
+                conf = Config()
+                assert conf.entity == "www.example.com"
+                assert conf.max_resolutions == 3
+                assert conf.no_color is False
+                assert conf.one_column is True
+                assert conf.use_shodan is True
+                assert conf.use_greynoise is False
+                assert conf.use_abuseipdb is False
+                assert conf.use_urlhaus is False
+                assert conf.vt_api_key == "foo"
+                assert conf.shodan_api_key == "hunter2"
+                assert conf.abuseipdb_api_key == ""
+                assert conf.greynoise_api_key == ""
+                assert conf.ip2whois_api_key == ""
         unset_env_vars()
 
     def test_defaults_2(self, fake_load_dotenv_2):
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_2):
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_2):
             with patch(
                 "sys.argv",
                 [
@@ -414,19 +471,18 @@ class TestDefaults:
                     "-s",
                 ],
             ):
-                parse_env()
-                args = parse_args()
-                assert args.entity == "www.example.com"
-                assert args.max_resolutions == 3
-                assert args.no_color is False
-                assert args.one_column is True
-                assert args.use_shodan is False
-                assert args.use_greynoise is False
-                assert args.use_urlhaus is False
+                conf = Config()
+                assert conf.entity == "www.example.com"
+                assert conf.max_resolutions == 3
+                assert conf.no_color is False
+                assert conf.one_column is True
+                assert conf.use_shodan is False
+                assert conf.use_greynoise is False
+                assert conf.use_urlhaus is False
         unset_env_vars()
 
     def test_defaults_3(self, fake_load_dotenv_3):
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_3):
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_3):
             with patch(
                 "sys.argv",
                 [
@@ -434,19 +490,18 @@ class TestDefaults:
                     "www.example.com",
                 ],
             ):
-                parse_env()
-                args = parse_args()
-                assert args.entity == "www.example.com"
-                assert args.max_resolutions == 3
-                assert args.no_color is True
-                assert args.one_column is False
-                assert args.use_shodan is False
-                assert args.use_greynoise is False
-                assert args.use_urlhaus is False
+                conf = Config()
+                assert conf.entity == "www.example.com"
+                assert conf.max_resolutions == 3
+                assert conf.no_color is True
+                assert conf.one_column is False
+                assert conf.use_shodan is False
+                assert conf.use_greynoise is False
+                assert conf.use_urlhaus is False
         unset_env_vars()
 
     def test_defaults_4(self, fake_load_dotenv_4):
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_4):
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_4):
             with patch(
                 "sys.argv",
                 [
@@ -455,15 +510,102 @@ class TestDefaults:
                     "-u",
                 ],
             ):
-                parse_env()
-                args = parse_args()
-                assert args.entity == "1.1.1.1"
-                assert args.no_color is False
-                assert args.one_column is False
-                assert args.use_shodan is False
-                assert args.use_greynoise is True
-                assert args.use_urlhaus is False
-                assert args.use_abuseipdb is True
+                conf = Config()
+                assert conf.entity == "1.1.1.1"
+                assert conf.no_color is False
+                assert conf.one_column is False
+                assert conf.use_shodan is False
+                assert conf.use_greynoise is True
+                assert conf.use_urlhaus is False
+                assert conf.use_abuseipdb is True
+                assert conf.abuseipdb_api_key == "dummy"
+        unset_env_vars()
+
+
+class TestAllFlag:
+    def test_1_ok(self, fake_load_dotenv_1):
+        """-A flag in argument"""
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_1):
+            with patch(
+                "sys.argv",
+                [
+                    "main",
+                    "www.example.com",
+                    "--all",
+                ],
+            ):
+                conf = Config()
+                assert conf.use_shodan is True
+                assert conf.use_greynoise is True
+                assert conf.use_urlhaus is True
+                assert conf.use_abuseipdb is True
+                assert conf.use_urlhaus is True
+        unset_env_vars()
+
+    def test_2_ok(self, fake_load_dotenv_all_ok):
+        """-A flag in config file"""
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_all_ok):
+            with patch(
+                "sys.argv",
+                [
+                    "main",
+                    "www.example.com",
+                ],
+            ):
+                conf = Config()
+                assert conf.use_shodan is True
+                assert conf.use_greynoise is True
+                assert conf.use_urlhaus is True
+                assert conf.use_abuseipdb is True
+                assert conf.use_urlhaus is True
+        unset_env_vars()
+
+    def test_3_error(self, fake_load_dotenv_1, capsys):
+        """Invalid arguments"""
+        with pytest.raises(SystemExit) as e:
+            with patch("wtfis.config.load_dotenv", fake_load_dotenv_1):
+                with patch(
+                    "sys.argv",
+                    [
+                        "main",
+                        "www.example.com",
+                        "-A",
+                        "-s",
+                    ],
+                ):
+                    _ = Config()
+
+        capture = capsys.readouterr()
+
+        assert capture.err == (
+            "usage: main [-h]\n"
+            "main: error: --use-* flags are not accepted when the --all/-A flag is set\n"
+        )
+        assert e.type == SystemExit
+        assert e.value.code == 2
+        unset_env_vars()
+
+    def test_4_error(self, fake_load_dotenv_all_invalid, capsys):
+        """Invalid WTFIS_DEFAULTS options"""
+        with pytest.raises(SystemExit) as e:
+            with patch("wtfis.config.load_dotenv", fake_load_dotenv_all_invalid):
+                with patch(
+                    "sys.argv",
+                    [
+                        "main",
+                        "www.example.com",
+                    ],
+                ):
+                    _ = Config()
+
+        capture = capsys.readouterr()
+
+        assert capture.err == (
+            "usage: main [-h]\n"
+            "main: error: --use-* flags are not accepted when the --all/-A flag is set\n"
+        )
+        assert e.type == SystemExit
+        assert e.value.code == 2
         unset_env_vars()
 
 
@@ -473,11 +615,11 @@ class TestGenEntityHandler:
     @patch("sys.argv", ["main", "www.example[.]com"])
     def test_handler_domain_1(self, fake_load_dotenv_1):
         """Domain with default params"""
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_1):
-            parse_env()
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_1):
+            conf = Config()
             console = Console()
             progress = (simulate_progress(console),)
-            entity = generate_entity_handler(parse_args(), console, progress)
+            entity = generate_entity_handler(conf, console, progress)
         assert isinstance(entity, DomainHandler)
         assert entity.entity == "www.example.com"
         assert entity.max_resolutions == 3
@@ -485,7 +627,7 @@ class TestGenEntityHandler:
         assert entity.progress == progress
         assert isinstance(entity._vt, VTClient)
         assert isinstance(entity._geoasn, IpWhoisClient)
-        assert isinstance(entity._whois, PTClient)
+        assert isinstance(entity._whois, Ip2WhoisClient)
         assert entity._shodan is None
         assert entity._greynoise is None
         assert entity._urlhaus is None
@@ -495,14 +637,14 @@ class TestGenEntityHandler:
     @patch("sys.argv", ["main", "www.example[.]com", "-s", "-g", "-u", "-m", "5"])
     def test_handler_domain_2(self, fake_load_dotenv_1):
         """Domain with Shodan and Greynoise and non-default max_resolutions"""
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_1):
-            parse_env()
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_1):
+            conf = Config()
             console = Console()
             progress = (simulate_progress(console),)
-            entity = generate_entity_handler(parse_args(), console, progress)
+            entity = generate_entity_handler(conf, console, progress)
         assert entity.max_resolutions == 5
         assert isinstance(entity._geoasn, IpWhoisClient)
-        assert isinstance(entity._whois, PTClient)
+        assert isinstance(entity._whois, Ip2WhoisClient)
         assert isinstance(entity._shodan, ShodanClient)
         assert isinstance(entity._greynoise, GreynoiseClient)
         assert isinstance(entity._urlhaus, UrlHausClient)
@@ -511,40 +653,40 @@ class TestGenEntityHandler:
     @patch("sys.argv", ["main", "www.example[.]com"])
     def test_handler_domain_3(self, fake_load_dotenv_vt_whois):
         """Domain using default Ip2Whois for whois"""
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_vt_whois):
-            parse_env()
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_vt_whois):
+            conf = Config()
             console = Console()
             progress = (simulate_progress(console),)
-            entity = generate_entity_handler(parse_args(), console, progress)
+            entity = generate_entity_handler(conf, console, progress)
         assert isinstance(entity._whois, VTClient)
         unset_env_vars()
 
     @patch("sys.argv", ["main", "www.example[.]com"])
     def test_handler_domain_4(self, fake_load_dotenv_ip2whois):
         """Domain using default Ip2Whois for whois"""
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_ip2whois):
-            parse_env()
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_ip2whois):
+            conf = Config()
             console = Console()
             progress = (simulate_progress(console),)
-            entity = generate_entity_handler(parse_args(), console, progress)
+            entity = generate_entity_handler(conf, console, progress)
         assert isinstance(entity._whois, Ip2WhoisClient)
         unset_env_vars()
 
     @patch("sys.argv", ["main", "1[.]1[.]1[.]1"])
     def test_handler_ip_1(self, fake_load_dotenv_1):
         """IP with default params"""
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_1):
-            parse_env()
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_1):
+            conf = Config()
             console = Console()
             progress = (simulate_progress(console),)
-            entity = generate_entity_handler(parse_args(), console, progress)
+            entity = generate_entity_handler(conf, console, progress)
         assert isinstance(entity, IpAddressHandler)
         assert entity.entity == "1.1.1.1"
         assert entity.console == console
         assert entity.progress == progress
         assert isinstance(entity._vt, VTClient)
         assert isinstance(entity._geoasn, IpWhoisClient)
-        assert isinstance(entity._whois, PTClient)
+        assert isinstance(entity._whois, VTClient)
         assert entity._greynoise is None
         assert entity._urlhaus is None
         unset_env_vars()
@@ -552,13 +694,13 @@ class TestGenEntityHandler:
     @patch("sys.argv", ["main", "1[.]1[.]1[.]1", "-s", "-g", "-u", "-a"])
     def test_handler_ip_2(self, fake_load_dotenv_1):
         """IP with various options"""
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_1):
-            parse_env()
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_1):
+            conf = Config()
             console = Console()
             progress = (simulate_progress(console),)
-            entity = generate_entity_handler(parse_args(), console, progress)
+            entity = generate_entity_handler(conf, console, progress)
         assert isinstance(entity._geoasn, IpWhoisClient)
-        assert isinstance(entity._whois, PTClient)
+        assert isinstance(entity._whois, VTClient)
         assert isinstance(entity._shodan, ShodanClient)
         assert isinstance(entity._greynoise, GreynoiseClient)
         assert isinstance(entity._urlhaus, UrlHausClient)
@@ -624,22 +766,21 @@ class TestGenView:
 class TestMain:
     @patch("sys.argv", ["main", "www.example.com"])
     @patch("wtfis.main.Console", return_value=Console())
-    @patch("wtfis.main.parse_args")
+    @patch("wtfis.main.Config")
     @patch("wtfis.main.get_progress")
     @patch("wtfis.main.generate_entity_handler", return_value=MagicMock())
     @patch("wtfis.main.generate_view", return_value=MagicMock())
     def test_main_default(
-        self, m_view, m_handler, m_progress, m_args, m_console, fake_load_dotenv_1
+        self, m_view, m_handler, m_progress, m_conf, m_console, fake_load_dotenv_1
     ):
         """Test all calls with default values"""
-        m_args.return_value = parse_args()
         m_progress.return_value = simulate_progress(m_console())
-        with patch("wtfis.main.load_dotenv", fake_load_dotenv_1):
+        with patch("wtfis.config.load_dotenv", fake_load_dotenv_1):
+            m_conf.return_value = Config()
             main()
-        m_args.assert_called_once_with()
-        m_handler.assert_called_once_with(m_args(), m_console(), m_progress())
+        m_handler.assert_called_once_with(m_conf(), m_console(), m_progress())
         m_handler().fetch_data.assert_called_once_with()
         m_handler().print_warnings.assert_called_once_with()
-        m_view.assert_called_once_with(m_args(), m_console(), m_handler())
+        m_view.assert_called_once_with(m_conf(), m_console(), m_handler())
         m_view().print.assert_called_once_with(one_column=False)
         unset_env_vars()
