@@ -6,7 +6,6 @@ from typing import Union
 
 from wtfis.clients.ip2whois import Ip2WhoisClient
 from wtfis.clients.ipwhois import IpWhoisClient
-from wtfis.clients.passivetotal import PTClient
 from wtfis.clients.virustotal import VTClient
 
 # IP geolocation and ASN client types
@@ -15,6 +14,5 @@ IpGeoAsnClientType = Union[IpWhoisClient,]
 # IP whois client types
 IpWhoisClientType = Union[
     Ip2WhoisClient,
-    PTClient,
     VTClient,
 ]
